@@ -3,11 +3,11 @@ from web3.main import Web3
 import json
 import time
 import requests
-from clients.keys import ARBITRUM_RPC, DIAMOND, REST_API, OrderSide, StopType, \
-    PositionSide, OrderType
+from clients.keys import REST_API, OrderSide, StopType, \
+    PositionSide, OrderType, Network, NONE_RPC
 from clients.utils import encode_bytes32
 import pkg_resources
-from clients.configs import GAS_LIMIT
+from clients.configs import GAS_LIMIT, CHAIN_CONFIG
 
 
 class ELFiBaseClient:
@@ -66,9 +66,11 @@ class ELFiBaseClient:
 
     
 class ELFiClient(ELFiBaseClient):
-    
-    def __init__(self, private_key, rpc=ARBITRUM_RPC, diamond=DIAMOND, rest_api=REST_API):
-        super().__init__(private_key, rpc, diamond, rest_api)
+    def __init__(self, private_key, network=Network.ARBITRUM, rpc=NONE_RPC):
+        if Network.BASE == network:
+            super().__init__(private_key, CHAIN_CONFIG['BASE']['RPC'] if rpc == NONE_RPC else rpc, CHAIN_CONFIG['BASE']['DIAMOND'], REST_API)
+        else:
+            super().__init__(private_key, CHAIN_CONFIG['ARBITRUM']['RPC'] if rpc == NONE_RPC else rpc, CHAIN_CONFIG['ARBITRUM']['DIAMOND'], REST_API)
         self._init_web3()
     
     def create_increase_market_order(self, symbol, marginToken, orderSide: OrderSide, orderMargin, leverage, isCrossMargin=True, executionFee=-1):
@@ -152,7 +154,7 @@ class ELFiClient(ELFiBaseClient):
         return self._sign_and_send_transaction(tx)
     
     def cancel_order(self, orderId):
-        tx = self._facet_contract("OrderFacet").functions.cancelOrder(orderId).build_transaction({
+        tx = self._facet_contract("OrderFacet").functions.cancelOrder(orderId, encode_bytes32('UserCancelOrder')).build_transaction({
                 'from': self.account,
                 'nonce': self.w3.eth.get_transaction_count(self.account)
             })
